import 'package:flutter/foundation.dart';
import 'package:flutter/services.dart';

import 'yundian_alive_platform_interface.dart';

/// An implementation of [YundianAlivePlatform] that uses method channels.
class MethodChannelYundianAlive extends YundianAlivePlatform {
  /// The method channel used to interact with the native platform.
  @visibleForTesting
  final methodChannel = const MethodChannel('yundian_alive');

  final aliveResultListener = const EventChannel(
      'yundian_alive.event.alive.result_listener');

  @override
  Future<String?> getPlatformVersion() async {
    final version =
    await methodChannel.invokeMethod<String>('getPlatformVersion');
    return version;
  }

  @override
  Future<String?> aliveEncryptAes(Map map) async {
    final version =
    await methodChannel.invokeMethod<String>('alive_encrypt_aes', map);
    return version;
  }

  @override
  Future<String?> aliveInit(Map map) async {
    final version = await methodChannel.invokeMethod<String>('alive_init', map);
    return version;
  }

  @override
  Future<String?> aliveStartDetect(Map map) async {
    final version =
    await methodChannel.invokeMethod<String>('alive_start_detect', map);
    return version;
  }

  @override
  onAliveResultListener(EventHandler onEvent, EventHandler onError) {
    aliveResultListener
        .receiveBroadcastStream()
        .listen(onEvent, onError: onError);
  }
}

typedef EventHandler = void Function(dynamic event);
